==> haskell-string-conversions-0.4.0.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: string-conversions
version: 0.4.0.1
id: string-conversions-0.4.0.1-4Kf1c6q8qP6CakUZjJ2l4Y
key: string-conversions-0.4.0.1-4Kf1c6q8qP6CakUZjJ2l4Y
license: BSD3
maintainer: soenkehahn@gmail.com
homepage: https://github.com/soenkehahn/string-conversions#readme
synopsis: Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.
category: Data
author: Sönke Hahn
exposed: True
indefinite: False
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic
abi: f32cb89438e7d323276302a8442d1d9b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/string-conversions-0.4.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/string-conversions-0.4.0.1
hs-libraries: HSstring-conversions-0.4.0.1-4Kf1c6q8qP6CakUZjJ2l4Y
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock
haddock-html: /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-string-conversions-0.4.0.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-string-conversions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: string-conversions
version: 0.4.0.1
id: string-conversions-0.4.0.1-G5jFYeIWeE2KOjFq2nva4C
key: string-conversions-0.4.0.1-G5jFYeIWeE2KOjFq2nva4C
license: BSD3
maintainer: soenkehahn@gmail.com
homepage: https://github.com/soenkehahn/string-conversions#readme
synopsis: Simplifies dealing with different types for strings
description:
    Provides a simple type class for converting values of different string types into values of other string types.
category: Data
author: Sönke Hahn
exposed: True
indefinite: False
exposed-modules:
    Data.String.Conversions Data.String.Conversions.Monomorphic
abi: 427cea7c17f05a5b5d5647f3ff8aee2e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/string-conversions-0.4.0.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/string-conversions-0.4.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/string-conversions-0.4.0.1
hs-libraries: HSstring-conversions-0.4.0.1-G5jFYeIWeE2KOjFq2nva4C
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
haddock-interfaces: /usr/share/doc/haskell-string-conversions/html/string-conversions.haddock
haddock-html: /usr/share/doc/haskell-string-conversions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
